@@ -443,6 +443,7 @@ class SetupCommand(AbstractInstallCommand):
             config_spec += '#' + plain_section
         config_file = config_spec[len('config:'):].split('#', 1)[0]
         config_file = os.path.join(os.getcwd(), config_file)
+        self.logging_file_config(config_file)
         conf = appconfig(config_spec, relative_to=os.getcwd())
         ep_name = conf.context.entry_point_name
         ep_group = conf.context.protocol
@@ -534,14 +535,22 @@ class Installer(object):
             if command.verbose:
                 print 'No %s found' % meta_name
             return self.simple_config(vars)
+        return self.template_renderer(
+            self.dist.get_metadata(meta_name), vars, filename=meta_name)
+
+    def template_renderer(self, content, vars, filename=None):
+        """
+        Subclasses may override this to provide different template
+        substitution (e.g., use a different template engine).
+        """
         if self.use_cheetah:
             import Cheetah.Template
-            tmpl = Cheetah.Template.Template(self.dist.get_metadata(meta_name),
-                                    searchList=[vars])
+            tmpl = Cheetah.Template.Template(content,
+                                             searchList=[vars])
             return copydir.careful_sub(
-                tmpl, vars, meta_name)
+                tmpl, vars, filename)
         else:
-            tmpl = string.Template(self.dist.get_metadata(meta_name))
+            tmpl = string.Template(content)
             return tmpl.substitute(vars)
 
     def simple_config(self, vars):
@@ -582,12 +591,14 @@ class Installer(object):
             mod = import_string.try_import_module(mod_name)
             if mod is None:
                 continue
-            if command.verbose:
-                print 'Running setup_config() from %s' % mod_name
             if hasattr(mod, 'setup_app'):
+                if command.verbose:
+                    print 'Running setup_app() from %s' % mod_name
                 self._call_setup_app(
                     mod.setup_app, command, filename, section, vars)
             elif hasattr(mod, 'setup_config'):
+                if command.verbose:
+                    print 'Running setup_config() from %s' % mod_name
                 mod.setup_config(command, filename, section, vars)
             else:
                 print 'No setup_app() or setup_config() function in %s (%s)' % (
@@ -601,3 +612,4 @@ class Installer(object):
         conf = appconfig(conf)
         conf.filename = filename
         func(command, conf, vars)
+
